# qec-util

![example workflow](https://github.com/MarcSerraPeralta/qec-util/actions/workflows/actions.yaml/badge.svg)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
![PyPI](https://img.shields.io/pypi/v/qec_util?label=pypi%20package)

A collection of utility methods and objects to aid with the simulation, decoding and analysis of QEC experiments.


## Installation

This package is available in PyPI, thus it can be installed using
```
pip install qec-util
```
or alternatively, it can be installed from source using
```
git clone git@github.com:MarcSerraPeralta/qec-util.git
pip install qec-util/
```
